Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1660)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java

Issue 2800803002: Fix test expectation. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java
index 5015d36aae42e93e026b19562c003cf0e3d4b821..7c4efe05b98269f5369c88f5dec9a9bf2d32ee68 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestBillingAddressTest.java
@@ -59,7 +59,7 @@ public class PaymentRequestBillingAddressTest extends PaymentRequestTestBase {
"Lisa Doe", "Google", "340 Main St", "CA", "Los Angeles", "", "90291", "", "US", "",
"jon.doe@gmail.com", "en-US"));
- // Incomplete profile (missing recipient).
+ // Incomplete profile (missing recipient name).
String profile6 = helper.setProfile(new AutofillProfile("", "https://example.com", true, "",
"Google", "340 Main St", "CA", "Los Angeles", "", "90291", "", "US", "650-253-0000",
"jon.doe@gmail.com", "en-US"));
@@ -317,14 +317,14 @@ public class PaymentRequestBillingAddressTest extends PaymentRequestTestBase {
.equals("Select"));
// The incomplete addresses in the dropdown contain edit required messages.
- assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX,
- 4).endsWith("Recipient required"));
+ assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX, 4)
+ .endsWith("Name required"));
assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX,
5).endsWith("More information required"));
assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX,
6).endsWith("Invalid address"));
// Selects the fourth billing addresss that misses recipient brings up the address
// editor.
setSpinnerSelectionsInCardEditorAndWait(new int[] {DECEMBER, NEXT_YEAR, 4}, mReadyToEdit);
setTextInEditorAndWait(new String[] {"Lisa Doh", "Google", "340 Main St", "Los Angeles",
@@ -352,8 +352,8 @@ public class PaymentRequestBillingAddressTest extends PaymentRequestTestBase {
.equals("Jon Doe, 340 Main St, Los Angeles, CA 90291"));
// The incomplete addresses in the dropdown contain edit required messages.
- assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX,
- 4).endsWith("Recipient required"));
+ assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX, 4)
+ .endsWith("Name required"));
assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX,
5).endsWith("More information required"));
assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX,
@@ -317,14 +317,14 @@ public class PaymentRequestBillingAddressTest extends PaymentRequestTestBase {
assertTrue(getSpinnerTextAtPositionInCardEditor(BILLING_ADDRESS_DROPDOWN_INDEX,
6).endsWith("Invalid address"));
- // Selects the fourth billing addresss that misses recipient brings up the address
+ // Selects the fourth billing addresss that misses recipient name brings up the address
// editor.
setSpinnerSelectionsInCardEditorAndWait(new int[] {DECEMBER, NEXT_YEAR, 4}, mReadyToEdit);
« no previous file with comments | « no previous file | chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestDynamicShippingMultipleAddressesTest.java » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698